#
#  --------------------------------------------------------------------------
#   Gurux Ltd
#
#
#
#  Filename: $HeadURL$
#
#  Version: $Revision$,
#                   $Date$
#                   $Author$
#
#  Copyright (c) Gurux Ltd
#
# ---------------------------------------------------------------------------
#
#   DESCRIPTION
#
#  This file is a part of Gurux Device Framework.
#
#  Gurux Device Framework is Open Source software; you can redistribute it
#  and/or modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; version 2 of the License.
#  Gurux Device Framework is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#  See the GNU General Public License for more details.
#
#  More information of Gurux products: http://www.gurux.org
#
#  This code is licensed under the GNU General Public License v2.
#  Full text may be retrieved at http://www.gnu.org/licenses/gpl-2.0.txt
# ---------------------------------------------------------------------------
from gurux_dlms.GXIntEnum import GXIntEnum


class ControlMode(GXIntEnum):
    """
    Configures the behaviour of the disconnect control object for all
    triggers, i.e.  the possible state transitions.
    """

    # pylint: disable=too-few-public-methods

    #
    # The disconnect control object is always in 'connected' state,
    #
    NONE = 0
    #
    # Disconnection: Remote =b, c manual =f local =g) Reconnection: Remote
    #  =d manual =e).
    #
    MODE_1 = 1
    #
    # Disconnection: Remote =b, c manual =f local =g) Reconnection: Remote
    #  =a manual =e).
    #
    MODE_2 = 2
    #
    # Disconnection: Remote =b, c manual =- local =g) Reconnection: Remote
    #  =d manual =e).
    #
    MODE_3 = 3
    #
    # Disconnection: Remote =b, c manual =- local =g) Reconnection: Remote
    #  =a manual =e)
    #
    MODE_4 = 4
    #
    # Disconnection: Remote =b, c manual =f local =g) Reconnection: Remote
    #  =d manual =e local =h
    #
    MODE_5 = 5
    #
    # Disconnection: Remote =b, c manual =- local =g) Reconnection: Remote
    #  =d manual =e local =h)
    #
    MODE_6 = 6
    #
    # Disconnection: Remote(b, c), manual(-), local(g)
    # Reconnection: Remote (a, i), manual (e), local (h)
    #
    DLMS_CONTROL_MODE_MODE_7 = 7



#
#  --------------------------------------------------------------------------
#   Gurux Ltd
#
#
#
#  Filename: $HeadURL$
#
#  Version: $Revision$,
#                   $Date$
#                   $Author$
#
#  Copyright (c) Gurux Ltd
#
# ---------------------------------------------------------------------------
#
#   DESCRIPTION
#
#  This file is a part of Gurux Device Framework.
#
#  Gurux Device Framework is Open Source software; you can redistribute it
#  and/or modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; version 2 of the License.
#  Gurux Device Framework is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#  See the GNU General Public License for more details.
#
#  More information of Gurux products: http:#www.gurux.org
#
#  This code is licensed under the GNU General Public License v2.
#  Full text may be retrieved at http:#www.gnu.org/licenses/gpl-2.0.txt
# ---------------------------------------------------------------------------

class GXPushConfirmationParameter:
    """
    Push confirmation parameters.
    """

    def __init__(self):
        self.__startDate = None
        self.__interval = None

    @property
    def startDate(self):
        """
        Confirmation start date. Fields of date-time not specified are not used.
        """
        return self.__startDate

    @startDate.setter
    def startDate(self, value):
        self.__startDate = value

    @property
    def interval(self):
        """
        Confirmation time interval in seconds. Disabled, if zero.
        """
        return self.__interval

    @interval.setter
    def interval(self, value):
        self.__interval = value



#
#  --------------------------------------------------------------------------
#   Gurux Ltd
#
#
#
#  Filename: $HeadURL$
#
#  Version: $Revision$,
#                   $Date$
#                   $Author$
#
#  Copyright (c) Gurux Ltd
#
# ---------------------------------------------------------------------------
#
#   DESCRIPTION
#
#  This file is a part of Gurux Device Framework.
#
#  Gurux Device Framework is Open Source software; you can redistribute it
#  and/or modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; version 2 of the License.
#  Gurux Device Framework is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#  See the GNU General Public License for more details.
#
#  More information of Gurux products: http://www.gurux.org
#
#  This code is licensed under the GNU General Public License v2.
#  Full text may be retrieved at http://www.gnu.org/licenses/gpl-2.0.txt
# ---------------------------------------------------------------------------
#
from setuptools import setup, find_packages

setup(
    name="gurux_dlms",
    version="1.0.180",
    author="Gurux Ltd",
    author_email="gurux@gurux.fi",
    description="Gurux DLMS library for Python.",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/gurux/gurux.dlms.python",
    packages=find_packages(),
    package_data={
        "gurux_dlms": [
            "OBISCodes.txt",
            "India.txt",
            "Italy.txt",
            "SaudiArabia.txt",
            "Spain.txt",
        ]
    },
    license="GPLv2",
    classifiers=[
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "License :: OSI Approved :: GNU General Public License v2 (GPLv2)",
        "Operating System :: OS Independent",
    ],
    install_requires=[],
)
